from genericpath import exists
from mufid.do_nothing import f as do_nothing
from os.path import exists
from os import mkdir

def f(path) : return [mkdir(path) if not exists(path) else do_nothing(), path][1]



from mufid.do_nothing import f as do_nothing
from mufid.mkdir import f as mkdir
from mufid.remove import f as remove
from mufid.load_pickle_object import f as load_pickle_object
from mufid.pickle_object_and_save import f as pickle_object_and_save
from mufid.load_yaml import f as load_yaml
from mufid.save_yaml import f as save_yaml


from re import M
from setuptools import find_packages, setup

setup(
  name='mufid',
  version='2.0',
  author='Yasar Adeel Ansari',
  author_email='yasaradeel@gmail.com',
  description='some useful functions',
  packages=find_packages('src'),
  package_dir={'': 'src'},
  classifiers=[
           "Programming Language :: Python :: 3",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent",
  ]
)